@@ -509,6 +509,8 @@ pub fn copy_template(
     let dest = dest.as_ref();
     let source = canonicalize(source)
         .map_err(|e| format!("Failed to canonicalize {}: {}", source.display(), e))?;
+    std::fs::create_dir_all(dest)
+        .map_err(|e| format!("Failed to create {}: {}", dest.display(), e))?;
     let dest = canonicalize(dest)
         .map_err(|e| format!("Failed to canonicalize {}: {}", dest.display(), e))?;
 
@@ -591,6 +593,19 @@ pub fn strip_trailing_slash(path: &std::path::Path) -> &std::path::Path {
     path.components().as_path()
 }
 
+pub(crate) fn display_relpath(path: impl AsRef<std::path::Path>) -> String {
+    let path = path.as_ref();
+    let relpath = if let Ok(cwd) = std::env::current_dir() {
+        match path.strip_prefix(cwd) {
+            Ok(path) => path,
+            Err(_) => path,
+        }
+    } else {
+        path
+    };
+    relpath.display().to_string()
+}
+
 #[cfg(test)]
 mod test {
     use super::*;
